@@ -2,7 +2,7 @@
 
 # install.sh file is part of slpkg.
 
-# Copyright 2014-2022 Dimitris Zlatanidis <d.zlatanidis@gmail.com>
+# Copyright 2014-2023 Dimitris Zlatanidis <d.zlatanidis@gmail.com>
 # All rights reserved.
 #
 # Redistribution and use of this script, with or without modification, is
@@ -24,8 +24,7 @@
 
 __version() {
 # Grab version from __metadata_.py file
-cat slpkg/__metadata__.py | grep "__version_info__ = (" \
-    | tr -d [[:space:]] | cut -c19-23 | tr , .
+cat setup.cfg | grep "version =" | tr -d "[:space:]" | cut -c9-13 | tr , .
 }
 
 PRGNAM=slpkg
@@ -33,7 +32,6 @@ VERSION=${VERSION:-$(__version)}
 
 # Installation script.
 # With this script allows you to install the slpkg as a Slackware package binary file.
-# Support wget download.
 ARCHIVES="$PRGNAM-$VERSION.tar.gz $PRGNAM-$VERSION.zip v$VERSION.tar.gz v$VERSION.zip \
 	      $PRGNAM-$VERSION.tar.bz2"
 cd ..
