@@ -8,12 +8,10 @@ config() {
   fi
 }
 
-CONFIGS="slpkg.conf repositories.conf blacklist slackware-mirrors default-repositories \
-    custom-repositories rlworkman.deps pkg_security"
-for file in $CONFIGS; do
-    config etc/slpkg/${file}.new
-done
+config etc/slpkg/slpkg.toml.new
+config etc/slpkg/repositories.toml.new
+config etc/slpkg/blacklist.toml.new
 
 if [ -x /usr/bin/update-desktop-database ]; then
   /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
-fi
\ No newline at end of file
+fi
